# CONSTITUTION.md テンプレート構造

## 確認対象セクション

```markdown
## 1. 存在意義（Purpose）
- このプロジェクトが存在する理由を明記する
```

## 未記入判定パターン

以下のパターンは「未記入」と判定する：

1. **テンプレート文言のまま**
   - 「このプロジェクトが存在する理由を明記する」
   - 「プロジェクトの目的を記載」
   - 「TODO」「TBD」「要記入」

2. **空のセクション**
   - セクション見出しのみで内容なし
   - 空白のみ

3. **プレースホルダー**
   - `{purpose}`
   - `[目的を記入]`
   - `___`

## 記入済み判定基準

以下の条件を満たす場合は「記入済み」と判定：

1. 具体的なプロジェクト目的が記載されている
2. テンプレート文言が置き換えられている
3. 1行以上の意味のある内容がある

## CONSTITUTION.md 全体構造

```markdown
# プロジェクト憲章（Constitution）

## 1. 存在意義（Purpose）
- [確認対象]

## 2. 基本原則（4つの原則）
1. 仕様は「生きたドキュメント」である
2. 仕様は「信頼できる唯一の情報源」とする
3. 仕様は「変更と反復が前提」とする
4. AIでコストを抑えて実現する（人間が最終判断）

## 3. 変更禁止の範囲（非交渉事項）
- この憲章は例外的事情を除き変更しない
- 変更する場合はPOが指示し、SMが実行、人間（ユーザー）が最終承認

## 4. ガバナンスと責任
- 最終判断：プロダクトオーナー（PO）
- 運用監督：スクラムマスター（SM）
- 実行責任：デベロッパー（Dev）

## 5. 合意形成と承認
- 指示はPOがqueue/po_to_sm.yamlで発行
- 決定事項はqueue/dashboard.mdに記録
- 最終承認は人間（ユーザー）が行う

## 6. セキュリティと品質
- 仕様とコードの整合性を常に確認
- AI出力は必ず人間がレビュー
```
